@@ -54,7 +54,7 @@ void CreationSourceWidget::emptyToggled(bool checked)
     setFinalPage(checked);
 }
 
-DictionaryCreationWizard::DictionaryCreationWizard(QWidget *parent, const char *name,
+DictionaryCreationWizard::DictionaryCreationWizard(QWidget *parent,
         const QStringList &dictionaryNames, const QStringList &dictionaryFiles,
         const QStringList &dictionaryLanguages)
     : QWizard(parent)
@@ -90,7 +90,7 @@ DictionaryCreationWizard::DictionaryCreationWizard(QWidget *parent, const char *
     kdeDocWidget->languageButton->showLanguageCodes(true);
     kdeDocWidget->languageButton->loadAllLanguages();
 
-    mergeWidget = new MergeWidget(this, "merge source page", dictionaryNames, dictionaryFiles, dictionaryLanguages);
+    mergeWidget = new MergeWidget(this, dictionaryNames, dictionaryFiles, dictionaryLanguages);
     mergeWidget->setTitle(i18n("Source of New Dictionary (2)"));
     mergeWidget->setFinalPage(true);
     setPage(MergePage, mergeWidget);
@@ -230,10 +230,11 @@ QString DictionaryCreationWizard::language()
 
 /***************************************************************************/
 
-MergeWidget::MergeWidget(QWidget *parent, const char *name,
+MergeWidget::MergeWidget(QWidget *parent,
                          const QStringList &dictionaryNames, const QStringList &dictionaryFiles,
                          const QStringList &dictionaryLanguages)
-    : QWizardPage(parent)
+    : QWizardPage(parent),
+      scrollArea(nullptr)
 {
     QGridLayout *layout = new QGridLayout(this);
     layout->setColumnStretch(0, 0);
@@ -303,6 +304,8 @@ CompletionWizardWidget::CompletionWizardWidget(QWidget *parent, const char *name
 {
     setupUi(this);
     setObjectName(QLatin1String(name));
+    languageButton->showLanguageCodes(true);
+    languageButton->loadAllLanguages();
 }
 
 CompletionWizardWidget::~CompletionWizardWidget()
@@ -323,7 +326,6 @@ void CompletionWizardWidget::ok()
     pdlg->close();
     delete pdlg;
 
-    QString filename;
     QString dictionaryFile;
 
     dictionaryFile = QStandardPaths::writableLocation(QStandardPaths::DataLocation) + QLatin1Char('/') + QStringLiteral("/");
